@@ -8,13 +8,12 @@ no warnings "experimental::signatures";
 no warnings "experimental::smartmatch";
 use Hash::Merge;
 
-our $VERSION = '0.05';
-
 require Exporter;
 
+our $VERSION = '0.07';
+
 our @ISA = qw(Exporter);
 our @EXPORT = qw(
-	notDefined
 	arrayElement
 	arrayLength
 	arrayMerge
@@ -44,12 +43,6 @@ our @EXPORT = qw(
 	makeInt
 );
 
-our $VERSION = '0.01';
-
-sub notDefined($element) {
-	my $notDefined = ! defined $element;
-	return $notDefined;
-}
 
 sub arrayDelete($array, $element) {
 	delete($array->[$element]);
@@ -86,23 +79,23 @@ sub arraySort($array) {
 sub arrayUnshift($array, $element) {
 	# Places the element at the beginning of an array,
 	# shifting all the values to the right
-	unshift($array, $element)
+	unshift(@{$array}, $element)
 }
 
 sub arrayShift($array) {
 	# Shifts the first value of the array off and returns it,
 	# shortening the array by 1 and moving everything down.
-	return shift($array);
+	return shift(@{$array});
 }
 
 sub arrayPush($array, $element) {
-	push($array, $element);
+	push(@{$array}, $element);
 }
 
 sub arrayPop($array) {
 	# Pops and returns the last value of the array,
 	# shortening the array by one element.
-	return pop($array);
+	return pop(@{$array});
 }
 
 sub makeInt($number) {
@@ -203,18 +196,7 @@ Rajkumar Reddy
 
 Copyright (C) 2022 by Rajkumar Reddy. All rights reserved.
 
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <https://www.gnu.org/licenses/>.
+Opensourced
 
 
 =cut
